@@ -30,3 +30,27 @@ SCREENS = dict(BASE_STRUCTURE)
 USERS = dict(BASE_STRUCTURE)
 USER_SPECIFIC = {"user_id": DataType.STRING, "ver": DataType.INT64}
 USERS.update(USER_SPECIFIC)
+
+GROUPS = dict(BASE_STRUCTURE)
+
+ALIASES = dict(BASE_STRUCTURE)
+
+TRACKS_TABLE = "tracks"
+SCREENS_TABLE = "screens"
+IDENTITIES_TABLE = "identities"
+PAGES_TABLE = "pages"
+USERS_TABLE = "users"
+ALIASES_TABLE = "aliases"
+GROUPS_TABLE = "groups"
+MISFITS_TABLE = "misfits"
+
+DEFAULT_TABLES = [
+    TRACKS_TABLE,
+    SCREENS_TABLE,
+    IDENTITIES_TABLE,
+    PAGES_TABLE,
+    USERS_TABLE,
+    ALIASES_TABLE,
+    GROUPS_TABLE,
+    MISFITS_TABLE
+]
